@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2
-id: persistent-sqlite-2.2-5a7ae9ddd357470bebf9abc310278dda
-key: persi_5VCQ8DZIr2kAiCcXAD62vI
+id: persistent-sqlite-2.2-918e76cf9874879ae8ba0bb4b826e3d9
+key: persi_3rEWvVqIxTJFksfvtANN13
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,20 +20,20 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2
-hs-libraries: HSpersistent-sqlite-2.2-5VCQ8DZIr2kAiCcXAD62vI
+hs-libraries: HSpersistent-sqlite-2.2-3rEWvVqIxTJFksfvtANN13
 extra-libraries:
     pthread
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-0dc23cc567e1e45fd451d3d7a1cbf2ca
+    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.17-d3b65fae3959e41c01434c1c220af3fd
+    monad-logger-0.3.18-2bfbe07c1c1cdc537fa81b345cec7330
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4-6358b6402a63bdc879cbf54a9eb5e6c6
-    resourcet-1.1.7.1-53b70bd9a277fdc9d256cfbf9605d278
+    persistent-2.2.4-3efd0b27ba9bd4f18bae3621104638b2
+    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
